McpEventExecutor class
Execution engine for the 25 MCP event types on the widget tree.
This is the only class that navigates the Flutter widget tree and executes actions on it. All the logic for "how to do X in Flutter" lives here.
Constructors
- McpEventExecutor(McpWidgetRegistry _registry, McpGestureSimulator _simulator)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeEvent(
{required String widgetKey, required McpEventType eventType, McpEventParams? params}) → Future< bool> -
Executes the
eventTypeevent on the widget identified bywidgetKey. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited