McpNavigatorObserver class

Observa los pushes/pops del Navigator y mantiene el route actual.

Singleton — usar McpNavigatorObserver.instance.

Compatible con cualquier Navigator (MaterialApp, GoRouter, Navigator directo). El nombre del route viene de RouteSettings.name, que GoRouter y Navigator populan automáticamente con el path (e.g. /marketplace, /orders/detail).

Inheritance

Properties

currentRoute String?
Ruta actual observada, o null si el observer no está registrado.
no setter
hashCode int
The hash code for this object.
no setterinherited
The navigator that the observer is observing, if any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
override
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
override
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance McpNavigatorObserver
final