McpWidgetType enum

Widget types supported by MCP

Inheritance
Available extensions

Values

button → const McpWidgetType
textField → const McpWidgetType
text → const McpWidgetType
list → const McpWidgetType
card → const McpWidgetType
image → const McpWidgetType
container → const McpWidgetType
checkbox → const McpWidgetType
radio → const McpWidgetType
switchWidget → const McpWidgetType
slider → const McpWidgetType
tab → const McpWidgetType
custom → const McpWidgetType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<McpWidgetType>
A constant List of the values in this enum, in order of their declaration.