McpEventServer class
HTTP server that exposes the E2E testing API to the external MCP server.
Runs inside the app in debug/profile mode. Listens on :7777 by default. Automatically stops when the app is closed (AppLifecycleState.detached). McpConnectivity configures platform forwarding on startup.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited