McpEventExecutor class

Motor de ejecución de los 25 tipos de eventos MCP sobre el widget tree.

Es la única clase que navega el árbol de widgets de Flutter y ejecuta acciones sobre él. Toda la lógica de "cómo hacer X en Flutter" vive aquí.

Constructors

McpEventExecutor(McpWidgetRegistry _registry, McpGestureSimulator _simulator)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeEvent({required String widgetKey, required McpEventType eventType, McpEventParams? params}) Future<bool>
Ejecuta el evento eventType sobre el widget identificado por widgetKey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited