McpScreenCapture class
Captures the screen using Flutter's internal layer tree.
Does not require additional widgets in the tree or special keys. Only available in debug/profile; returns error in release.
Usage:
final json = await McpScreenCapture.capture();
if (json.containsKey('error')) {
// not available (release mode or error)
} else {
final base64 = json['base64'] as String;
// send as MCP image or display
}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited