McpEventParams class
Additional parameters for events
Constructors
- McpEventParams({String? text, Duration? duration, double? distance, String? direction, double? deltaX, double? deltaY, bool? clearFirst, String? expectedText, Offset? targetPosition, double? scale, String? dropdownValue, int? dropdownIndex, double? sliderValue, String? targetKey, int? maxScrollAttempts, String? label, int? expectedCount, double? dx, double? dy})
-
const
-
McpEventParams.fromJson(Map<
String, dynamic> json) -
Create from Map (useful for HTTP requests)
factory
Properties
- clearFirst → bool?
-
final
- deltaX → double?
-
final
- deltaY → double?
-
final
- direction → String?
-
final
- distance → double?
-
final
- dropdownIndex → int?
-
final
- dropdownValue → String?
-
final
- duration → Duration?
-
final
- dx → double?
-
final
- dy → double?
-
final
- expectedCount → int?
-
final
- expectedText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- maxScrollAttempts → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double?
-
final
- sliderValue → double?
-
final
- targetKey → String?
-
final
- targetPosition → Offset?
-
final
- text → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to Map (useful for logging)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited