McpConnectivity class
Configures connectivity between the app and the MCP server based on the platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setup(
{required int appPort, int? forwardPort}) → Future< McpConnectivityInfo> - Configures port forwarding for the current platform and returns connectivity information for logs/debug.